lintel-check
Check command for Lintel. Provides the lintel check subcommand which runs schema validation and additional checks.
The core validation engine lives in lintel-validate. This crate defines the bpaf CLI arguments for the check command and delegates to lintel-validate for validation.
License
Apache-2.0
Structs
Functions
- check
- Run all checks and return the result without reporting.
- check_
args - Construct the bpaf parser for
CheckArgs. - run
- Run all checks: schema validation and formatting.