Module validate

Module validate 

Structs

CheckedFile
A file that was checked and the schema it resolved to.
ValidateArgs
ValidateResult
Result of a validation run.

Enums

LintError
A single lint error produced during validation.

Functions

run
Errors
run_with
Like run, but calls on_check each time a file is checked, allowing callers to stream progress (e.g. verbose output) as files are processed.