lintel-check
Check command for Lintel. Provides the lintel check subcommand which runs schema validation and additional checks.
The core validation engine lives in lintel-validate. This crate defines the bpaf CLI arguments for the check command and delegates to lintel-validate for validation.
License
Apache-2.0
Structs
Traits
- Reporter
- Trait for formatting and outputting validation results.
Functions
- check_
args - Construct the bpaf parser for
CheckArgs. - run
- Run all checks: schema validation (and formatting in the future).