pub async fn check(
args: &mut CheckArgs,
on_file_checked: impl FnMut(&CheckedFile),
) -> Result<CheckResult>Expand description
Run all checks and return the result without reporting.
Calls on_file_checked for each file as it is validated (for streaming
progress). The caller is responsible for reporting the result.
Errors
Returns an error if schema validation fails to run (e.g. network or I/O issues).