Module validate
lintel_
check
0.0.3
Module validate
Module Items
Structs
Enums
Functions
In crate lintel_
check
lintel_check
Module
validate
Structs

Checked
File
A file that was checked and the schema it resolved to.
Validate
Args
Validate
Result
Result of a validation run.
Enums

Lint
Error
A single lint error produced during validation.
Functions

run
Errors
run_
with
Like
run
, but calls
on_check
each time a file is checked, allowing callers to stream progress (e.g. verbose output) as files are processed.